import { select,csv,
        scaleLinear,max,extent,axisLeft,scaleTime,
        line,curveBasis,area,
        axisBottom, format} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');


const render = data =>{
  const xValue = d => d.timestamp;
  const yValue = d => d.temperature;
  
  const margin = {top:50, right:70, bottom:250, left:200}
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = width - margin.top - margin.bottom;
  
  const xAixaLabel = 'Time';
  const yAixaLabel = 'Temperature';
  const title = '' + yAixaLabel + ' vs. '
  + xAixaLabel;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth]);
  
  const yScale = scaleLinear()
		.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const yAxis = axisLeft(yScale);
  const xAxis = axisBottom(xScale);
  
  yAxis.tickSize(-innerWidth)
  	.tickPadding(10);
  
  xAxis.ticks(6).tickSize(-innerHeight)
  	.tickPadding(15);
  
  const g = svg.append('g')
  	.attr('transform',`translate(${margin.left},${margin.top})`);
  
  // yAxis(g.append('g'));
  
  // fixed yAxis
  const yAixsG = g.append('g').call(yAxis);
  yAixsG.selectAll('.domain').remove();
  yAixsG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -70)
  	.attr('x', -innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('transform', 'rotate(-90)')
  	.style('text-anchor', 'middle')
  	.text(yAixaLabel);
  
  
  // fixed xAxis
  const xAxisG = g.append('g').call(xAxis)
		.attr('transform',`translate(0,${innerHeight})`)
  	
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 80)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAixaLabel);
  
  const areaGenerate = area()
  	.x(d=>xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d=>yScale(yValue(d)))
  	.curve(curveBasis);//smooth line
  
  g.append('path')
  	.attr('class','line-path')
  	.attr('d', areaGenerate(data));

  // add title
  g.append('text')
  	.attr('class', 'title')
  	.attr('x', 20)
  	.attr('y', -12)
  	.text(title);
};


// csv('data.csv').then(data=>{
// csv('https://vizhub.com/curran/datasets/world-population-by-year-2015.csv').then(data=>{
//   data.forEach(d=>{

csv('temperature.csv').then(data =>{
  data.forEach(d=>{
  	d.temperature = +d.temperature;
    d.timestamp = new Date(d.timestamp);
  });
	render(data);
});